==> nextcloud-app-tasks-0.15.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/id.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Penting",
    "Today" : "Hari Ini",
    "Week" : "Minggu",
    "All" : "Semua",
    "Current" : "Saat ini",
    "Completed" : "Selesai",
    "Tasks" : "Tugas",
    "The Tasks app for Nextcloud" : "Aplikasi Tugas untuk Nextcloud",
    "Visibility of Smart Collections" : "Visibilitas Koleksi Cerdas",
    "Hidden" : "Sembunyi",
    "Visible" : "Tampak",
    "Automatic" : "Otomatis",
    "Share with users or groups" : "Bagi dengan pengguna atau grup",
    "No users or groups" : "Tidak ada pengguna atau grup",
    "Can edit" : "Can edit",
    "Unshare with {displayName}" : "Batal berbagi dengan {displayName}",
    "Edit" : "Sunting",
    "Copy private link" : "Salin tautan privat",
    "Copied" : "Tersalin",
    "Export" : "Ekspor",
    "Delete" : "Hapus",
    "Unshare" : "Batalkan berbagi",
    "List name" : "Nama daftar",
    "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
    "Calendar link could not be copied to clipboard." : "Tautan kalender tidak dapat disalin ke papan klip.",
    "An empty name is not allowed." : "Nama kosong tidak diperbolehkan.",
    "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
    "Name" : "Nama",
    "Deleted" : "Dihapus",
    "Restore" : "Pulihkan",
    "Delete permanently" : "Hapus secara permanen",
    "Empty trash bin" : "Kosongkan tempat sampah",
    "Untitled task" : "Tugas tanpa judul",
    "Untitled event" : "Acara tanpa judul",
    "Due date" : "Tenggat",
    "Last modified" : "Terakhir diubah",
    "[Today]" : "[Hari ini]",
    "Cancel" : "Batal",
    "Close" : "Tutup",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tugas Diselesaikan"],
    "Tomorrow" : "Besok",
    "All day" : "Sepanjang hari",
    "Details" : "Detail",
    "Notes" : "Catatan",
    "Reminders" : "Pengingat",
    "Repeat" : "Ulang",
    "Task not found!" : "Tugas tidak ditemukan!",
    "[Starts today]" : "[Dimulai hari ini]",
    "Set start date" : "Atur tanggal mulai",
    "Set due date" : "Atur tanggal jatuh tempo",
    "Mark as done" : "Tandai sebagai selesai",
    "An error occurred" : "Terjadi kesalahan"
},
"nplurals=1; plural=0;");

==> nextcloud-app-tasks-0.16.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/id.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Penting",
    "Today" : "Hari Ini",
    "Week" : "Minggu",
    "All" : "Semua",
    "Current" : "Saat ini",
    "Completed" : "Selesai",
    "Tasks" : "Tugas",
    "The Tasks app for Nextcloud" : "Aplikasi Tugas untuk Nextcloud",
    "Visibility of Smart Collections" : "Visibilitas Koleksi Cerdas",
    "Hidden" : "Sembunyi",
    "Visible" : "Tampak",
    "Automatic" : "Otomatis",
    "Share with users or groups" : "Bagi dengan pengguna atau grup",
    "No users or groups" : "Tidak ada pengguna atau grup",
    "Can edit" : "Can edit",
    "Unshare with {displayName}" : "Batal berbagi dengan {displayName}",
    "Edit" : "Sunting",
    "Copy private link" : "Salin tautan privat",
    "Copied" : "Tersalin",
    "Export" : "Ekspor",
    "Delete" : "Hapus",
    "Unshare" : "Batalkan berbagi",
    "List name" : "Nama daftar",
    "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
    "Calendar link could not be copied to clipboard." : "Tautan kalender tidak dapat disalin ke papan klip.",
    "An empty name is not allowed." : "Nama kosong tidak diperbolehkan.",
    "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
    "Trash bin" : "Keranjang sampah",
    "Name" : "Nama",
    "Deleted" : "Dihapus",
    "Restore" : "Pulihkan",
    "Delete permanently" : "Hapus secara permanen",
    "Empty trash bin" : "Kosongkan tempat sampah",
    "Untitled task" : "Tugas tanpa judul",
    "Untitled event" : "Acara tanpa judul",
    "Untitled item" : "Item tanpa judul",
    "Unknown calendar" : "Kalender tidak diketahui",
    "Could not load deleted calendars and objects" : "Tidak dapat memuat kalender dan objek yang dihapus",
    "Could not restore calendar or event" : "Tidak dapat memulihkan kalender atau acara",
    "Do you really want to empty the trash bin?" : "Apakah Anda benar-benar ingin mengosongkan keranjang sampah?",
    "Cancel" : "Batal",
    "Close" : "Tutup",
    "Select tags to filter by" : "Pilih tag untuk disaring",
    "Due date" : "Tenggat",
    "Last modified" : "Terakhir diubah",
    "Alphabetically" : "Berdasarkan abjad",
    "[Today]" : "[Hari ini]",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tugas Diselesaikan"],
    "Tomorrow" : "Besok",
    "All day" : "Sepanjang hari",
    "Details" : "Detail",
    "Notes" : "Catatan",
    "Reminders" : "Pengingat",
    "Repeat" : "Ulang",
    "Task not found!" : "Tugas tidak ditemukan!",
    "Set start date" : "Atur tanggal mulai",
    "Set due date" : "Atur tanggal jatuh tempo",
    "Mark as done" : "Tandai sebagai selesai",
    "An error occurred" : "Terjadi kesalahan",
    "[Starts today]" : "[Dimulai hari ini]"
},
"nplurals=1; plural=0;");
